UnexpectedErrorEffect class
Error effect that is emitted by SafeBloc/SafeCubit if exception in its event handler/method occurs.
- Inheritance
-
- Object
- BaseEffect
- UnexpectedErrorEffect
- Implemented types
Constructors
- UnexpectedErrorEffect(UnexpectedError error)
-
const
Properties
- error → UnexpectedError
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited